@@ -50,7 +50,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-model')}
       it { is_expected.to contain_nova_config('libvirt/cpu_models').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
@@ -64,6 +64,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/images_type').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value('<SERVICE DEFAULT>')}
@@ -109,7 +110,7 @@ describe 'nova::compute::libvirt' do
           :nfs_mount_options                          => 'rw,intr,nolock',
           :num_pcie_ports                             => 16,
           :mem_stats_period_seconds                   => 20,
-          :pmem_namespaces                            => '128G:ns0|ns1|ns2|ns3',
+          :pmem_namespaces                            => ['128G:ns0|ns1|ns2|ns3', '262144MB:ns4|ns5', 'MEDIUM:ns6|ns7'],
           :swtpm_enabled                              => true,
           :swtpm_user                                 => 'libvirt',
           :swtpm_group                                => 'libvirt',
@@ -150,7 +151,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value(16)}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
-      it { is_expected.to contain_nova_config('libvirt/pmem_namespaces').with_value("128G:ns0|ns1|ns2|ns3")}
+      it { is_expected.to contain_nova_config('libvirt/pmem_namespaces').with_value('128G:ns0|ns1|ns2|ns3,262144MB:ns4|ns5,MEDIUM:ns6|ns7')}
       it { is_expected.to contain_nova_config('libvirt/swtpm_enabled').with_value(true)}
       it { is_expected.to contain_nova_config('libvirt/swtpm_user').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
@@ -158,19 +159,19 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
       it {
         is_expected.to contain_service('libvirt').with(
-          :name     => 'custom_service',
-          :enable   => true,
-          :ensure   => 'running',
-          :before   => ['Service[nova-compute]']
+          :name   => 'custom_service',
+          :enable => true,
+          :ensure => 'running',
+          :before => ['Anchor[nova::service::end]', 'Service[nova-compute]']
         )
         is_expected.to contain_service('virtlockd').with(
-          :name     => 'virtlock',
-          :enable   => true,
+          :name   => 'virtlock',
+          :enable => true,
           :ensure => 'running'
         )
         is_expected.to contain_service('virtlogd').with(
-          :name     => 'virtlog',
-          :enable   => true,
+          :name   => 'virtlog',
+          :enable => true,
           :ensure => 'running'
         )
 
@@ -265,12 +266,12 @@ describe 'nova::compute::libvirt' do
         :name   => 'libvirtd',
         :enable => true,
         :ensure => 'running',
-        :before => ['Service[nova-compute]'],
+        :before => ['Anchor[nova::service::end]', 'Service[nova-compute]'],
       )}
       it { is_expected.to contain_service('messagebus').with(
         :ensure => 'running',
         :enable => true,
-        :before => ['Service[libvirt]'],
+        :before => ['Anchor[nova::service::end]', 'Service[libvirt]'],
         :name   => 'dbus'
       ) }
 
