@@ -23,11 +23,7 @@ require 'spec_helper'
 describe 'nova::compute::rbd' do
 
   let :params do
-    { :libvirt_rbd_user             => 'nova',
-      :libvirt_rbd_secret_uuid      => false,
-      :libvirt_images_rbd_pool      => 'rbd',
-      :libvirt_images_rbd_ceph_conf => '/etc/ceph/ceph.conf',
-      :ephemeral_storage            => true }
+    { :libvirt_rbd_user => 'nova' }
   end
 
   shared_examples_for 'nova compute rbd' do
@@ -38,22 +34,29 @@ describe 'nova::compute::rbd' do
         is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_value('rbd')
         is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_value('/etc/ceph/ceph.conf')
         is_expected.to contain_nova_config('libvirt/rbd_user').with_value('nova')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_value('<SERVICE DEFAULT>')
     end
 
     it 'installs client package' do
       is_expected.to contain_package('ceph-client-package').with(
         'name'   => platform_params[:ceph_client_package],
-        'ensure' => 'present'
+        'ensure' => 'present',
+        'tag'    => ['openstack', 'nova-support-package']
       )
     end
 
     context 'when overriding default parameters' do
       before :each do
         params.merge!(
-          :libvirt_rbd_user             => 'joe',
-          :libvirt_rbd_secret_uuid      => false,
-          :libvirt_images_rbd_pool      => 'AnotherPool',
-          :libvirt_images_rbd_ceph_conf => '/tmp/ceph.conf'
+          :libvirt_rbd_user                             => 'joe',
+          :libvirt_rbd_secret_uuid                      => false,
+          :libvirt_images_rbd_pool                      => 'AnotherPool',
+          :libvirt_images_rbd_ceph_conf                 => '/tmp/ceph.conf',
+          :libvirt_images_rbd_glance_store_name         => 'glance_rbd_store',
+          :libvirt_images_rbd_glance_copy_poll_interval => 30,
+          :libvirt_images_rbd_glance_copy_timeout       => 300
         )
       end
 
@@ -61,6 +64,9 @@ describe 'nova::compute::rbd' do
           is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_value('AnotherPool')
           is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_value('/tmp/ceph.conf')
           is_expected.to contain_nova_config('libvirt/rbd_user').with_value('joe')
+          is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_value('glance_rbd_store')
+          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_value(30)
+          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_value(300)
       end
     end
 
@@ -91,7 +97,8 @@ describe 'nova::compute::rbd' do
           :require => 'File[/etc/nova/secret.xml]',
         )
         is_expected.to contain_exec('set-secret-value virsh').with(
-          :command => "/usr/bin/virsh secret-set-value --secret UUID --base64 $(ceph auth get-key client.rbd_test)"
+          :command   => "/usr/bin/virsh secret-set-value --secret UUID --base64 $(ceph auth get-key client.rbd_test)",
+          :logoutput => false,
         )
       end
     end
@@ -106,7 +113,8 @@ describe 'nova::compute::rbd' do
 
       it 'set libvirt secret key from passed key' do
         is_expected.to contain_exec('set-secret-value virsh').with(
-          :command => "/usr/bin/virsh secret-set-value --secret #{params[:libvirt_rbd_secret_uuid]} --base64 #{params[:libvirt_rbd_secret_key]}"
+          :command   => "/usr/bin/virsh secret-set-value --secret #{params[:libvirt_rbd_secret_uuid]} --base64 #{params[:libvirt_rbd_secret_key]}",
+          :logoutput => false,
         )
       end
     end
@@ -121,8 +129,11 @@ describe 'nova::compute::rbd' do
       end
 
       it 'should only set user and secret_uuid in nova.conf ' do
-          is_expected.to_not contain_nova_config('libvirt/images_rbd_pool').with_value('rbd')
-          is_expected.to_not contain_nova_config('libvirt/images_rbd_ceph_conf').with_value('/etc/ceph/ceph.conf')
+          is_expected.to contain_nova_config('libvirt/images_rbd_pool').with_ensure('absent')
+          is_expected.to contain_nova_config('libvirt/images_rbd_ceph_conf').with_ensure('absent')
+          is_expected.to contain_nova_config('libvirt/images_rbd_glance_store_name').with_ensure('absent')
+          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_poll_interval').with_ensure('absent')
+          is_expected.to contain_nova_config('libvirt/images_rbd_glance_copy_timeout').with_ensure('absent')
           is_expected.to contain_nova_config('libvirt/rbd_user').with_value('nova')
           is_expected.to contain_nova_config('libvirt/rbd_secret_uuid').with_value('UUID')
       end
@@ -142,7 +153,8 @@ describe 'nova::compute::rbd' do
           :require => 'File[/etc/nova/secret.xml]',
         )
         is_expected.to contain_exec('set-secret-value virsh').with(
-          :command => "/usr/bin/virsh secret-set-value --secret UUID --base64 $(ceph auth get-key client.rbd_test)"
+          :command   => "/usr/bin/virsh secret-set-value --secret UUID --base64 $(ceph auth get-key client.rbd_test)",
+          :logoutput => false,
         )
       end
     end
@@ -169,7 +181,7 @@ describe 'nova::compute::rbd' do
       let (:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          { :ceph_client_package => 'ceph' }
+          { :ceph_client_package => 'ceph-common' }
         when 'RedHat'
           { :ceph_client_package => 'ceph-common' }
         end
